def print_lol(the_list,level=0):
	for each_item in the_list:
		if isinstance(each_item, list):
			print_lol(each_item,level)
		else:
			for tab_stop in range(level+1):
				print("\t",end='')
			print(each_item)


from distutils.core import setup

setup(
		name 			='nester_list',
		version			='1.2.0',
		py_modules		=['nester_list'],
		author			='Jasmin Softic',
		author_email	='jasoftic@gmail.com',
		url				='http://www.sacgc.org',
		description		='A simple printer of nester lists',
	)




	